# Autogenerated by nbdev

d = { 'settings': { 'allowed_cell_metadata_keys': '',
                'allowed_metadata_keys': '',
                'audience': 'Developers',
                'author': 'Franck Albinet',
                'author_email': 'franckalbinet@gmail.com',
                'black_formatting': 'False',
                'branch': 'main',
                'clean_ids': 'True',
                'copyright': 'Franck Albinet',
                'custom_quarto_yml': 'True',
                'custom_sidebar': 'True',
                'description': 'Prediction of Exchangeable Potassium in Soil through Mid-Infrared and Deep Learning paper code',
                'doc_baseurl': '/mirzai/',
                'doc_host': 'https://franckalbinet.github.io',
                'doc_path': '_docs',
                'git_url': 'https://github.com/franckalbinet/mirzai/',
                'host': 'github',
                'jupyter_hooks': 'True',
                'keywords': 'high-throughput soil characterization remediation',
                'language': 'English',
                'lib_name': 'mirzai',
                'lib_path': 'mirzai',
                'license': 'apache2',
                'min_python': '3.7',
                'nbs_path': 'nbs',
                'readme_nb': 'index.ipynb',
                'recursive': 'False',
                'repo': 'mirzai',
                'requirements': 'numpy pandas fastcore scipy matplotlib>=3.5.1 scikit-learn torch torchvision tqdm captum',
                'status': '2',
                'title': 'mirzai',
                'tst_flags': 'notest',
                'user': 'franckalbinet',
                'version': '0.2.0'},
  'syms': { 'mirzai.data.loading': {'mirzai.data.loading.load_kssl': 'https://franckalbinet.github.io/mirzai/data.loading.html#load_kssl'},
            'mirzai.data.selection': { 'mirzai.data.selection.get_y_by_order': 'https://franckalbinet.github.io/mirzai/data.selection.html#get_y_by_order',
                                       'mirzai.data.selection.select_X': 'https://franckalbinet.github.io/mirzai/data.selection.html#select_x',
                                       'mirzai.data.selection.select_tax_order': 'https://franckalbinet.github.io/mirzai/data.selection.html#select_tax_order',
                                       'mirzai.data.selection.select_y': 'https://franckalbinet.github.io/mirzai/data.selection.html#select_y'},
            'mirzai.data.torch': { 'mirzai.data.torch.DataLoaders': 'https://franckalbinet.github.io/mirzai/data.torch.html#dataloaders',
                                   'mirzai.data.torch.DataLoaders.loaders': 'https://franckalbinet.github.io/mirzai/data.torch.html#dataloaders.loaders',
                                   'mirzai.data.torch.Noop': 'https://franckalbinet.github.io/mirzai/data.torch.html#noop',
                                   'mirzai.data.torch.SNV_transform': 'https://franckalbinet.github.io/mirzai/data.torch.html#snv_transform',
                                   'mirzai.data.torch.SpectralDataset': 'https://franckalbinet.github.io/mirzai/data.torch.html#spectraldataset'},
            'mirzai.data.transform': { 'mirzai.data.transform.CO2_REGION': 'https://franckalbinet.github.io/mirzai/data.transform.html#co2_region',
                                       'mirzai.data.transform.DropSpectralRegions': 'https://franckalbinet.github.io/mirzai/data.transform.html#dropspectralregions',
                                       'mirzai.data.transform.DropSpectralRegions.fit': 'https://franckalbinet.github.io/mirzai/data.transform.html#dropspectralregions.fit',
                                       'mirzai.data.transform.DropSpectralRegions.transform': 'https://franckalbinet.github.io/mirzai/data.transform.html#dropspectralregions.transform',
                                       'mirzai.data.transform.SNV': 'https://franckalbinet.github.io/mirzai/data.transform.html#snv',
                                       'mirzai.data.transform.SNV.fit': 'https://franckalbinet.github.io/mirzai/data.transform.html#snv.fit',
                                       'mirzai.data.transform.SNV.transform': 'https://franckalbinet.github.io/mirzai/data.transform.html#snv.transform',
                                       'mirzai.data.transform.TakeDerivative': 'https://franckalbinet.github.io/mirzai/data.transform.html#takederivative',
                                       'mirzai.data.transform.TakeDerivative.fit': 'https://franckalbinet.github.io/mirzai/data.transform.html#takederivative.fit',
                                       'mirzai.data.transform.TakeDerivative.transform': 'https://franckalbinet.github.io/mirzai/data.transform.html#takederivative.transform',
                                       'mirzai.data.transform.log_transform_y': 'https://franckalbinet.github.io/mirzai/data.transform.html#log_transform_y'},
            'mirzai.training.cnn': { 'mirzai.training.cnn.Evaluator': 'https://franckalbinet.github.io/mirzai/training.cnn.html#evaluator',
                                     'mirzai.training.cnn.Evaluator.eval_on_test': 'https://franckalbinet.github.io/mirzai/training.cnn.html#evaluator.eval_on_test',
                                     'mirzai.training.cnn.Evaluator.eval_on_train': 'https://franckalbinet.github.io/mirzai/training.cnn.html#evaluator.eval_on_train',
                                     'mirzai.training.cnn.Evaluator.reduce': 'https://franckalbinet.github.io/mirzai/training.cnn.html#evaluator.reduce',
                                     'mirzai.training.cnn.Evaluator.train_multiple': 'https://franckalbinet.github.io/mirzai/training.cnn.html#evaluator.train_multiple',
                                     'mirzai.training.cnn.Learner': 'https://franckalbinet.github.io/mirzai/training.cnn.html#learner',
                                     'mirzai.training.cnn.Learner.eval': 'https://franckalbinet.github.io/mirzai/training.cnn.html#learner.eval',
                                     'mirzai.training.cnn.Learner.fit': 'https://franckalbinet.github.io/mirzai/training.cnn.html#learner.fit',
                                     'mirzai.training.cnn.Learner.predict': 'https://franckalbinet.github.io/mirzai/training.cnn.html#learner.predict',
                                     'mirzai.training.cnn.Model': 'https://franckalbinet.github.io/mirzai/training.cnn.html#model',
                                     'mirzai.training.cnn.Model.forward': 'https://franckalbinet.github.io/mirzai/training.cnn.html#model.forward',
                                     'mirzai.training.cnn.Model.make_convpool_block': 'https://franckalbinet.github.io/mirzai/training.cnn.html#model.make_convpool_block',
                                     'mirzai.training.cnn.weights_init': 'https://franckalbinet.github.io/mirzai/training.cnn.html#weights_init'},
            'mirzai.training.core': {'mirzai.training.core.is_plateau': 'https://franckalbinet.github.io/mirzai/training.core.html#is_plateau'},
            'mirzai.training.metrics': { 'mirzai.training.metrics.eval_reg': 'https://franckalbinet.github.io/mirzai/training.metrics.html#eval_reg',
                                         'mirzai.training.metrics.lccc': 'https://franckalbinet.github.io/mirzai/training.metrics.html#lccc',
                                         'mirzai.training.metrics.mape': 'https://franckalbinet.github.io/mirzai/training.metrics.html#mape',
                                         'mirzai.training.metrics.rpd': 'https://franckalbinet.github.io/mirzai/training.metrics.html#rpd',
                                         'mirzai.training.metrics.rpiq': 'https://franckalbinet.github.io/mirzai/training.metrics.html#rpiq',
                                         'mirzai.training.metrics.stb': 'https://franckalbinet.github.io/mirzai/training.metrics.html#stb'},
            'mirzai.training.plsr': { 'mirzai.training.plsr.Evaluator': 'https://franckalbinet.github.io/mirzai/training.plsr.html#evaluator',
                                      'mirzai.training.plsr.Evaluator.eval_on_test': 'https://franckalbinet.github.io/mirzai/training.plsr.html#evaluator.eval_on_test',
                                      'mirzai.training.plsr.Evaluator.eval_on_train': 'https://franckalbinet.github.io/mirzai/training.plsr.html#evaluator.eval_on_train',
                                      'mirzai.training.plsr.Evaluator.reduce': 'https://franckalbinet.github.io/mirzai/training.plsr.html#evaluator.reduce',
                                      'mirzai.training.plsr.Evaluator.train_multiple': 'https://franckalbinet.github.io/mirzai/training.plsr.html#evaluator.train_multiple',
                                      'mirzai.training.plsr.Learner': 'https://franckalbinet.github.io/mirzai/training.plsr.html#learner',
                                      'mirzai.training.plsr.Learner.evaluate': 'https://franckalbinet.github.io/mirzai/training.plsr.html#learner.evaluate',
                                      'mirzai.training.plsr.Learner.find_hp': 'https://franckalbinet.github.io/mirzai/training.plsr.html#learner.find_hp',
                                      'mirzai.training.plsr.Learner.fit': 'https://franckalbinet.github.io/mirzai/training.plsr.html#learner.fit',
                                      'mirzai.training.plsr.PLS_model': 'https://franckalbinet.github.io/mirzai/training.plsr.html#pls_model',
                                      'mirzai.training.plsr.PLS_model.eval': 'https://franckalbinet.github.io/mirzai/training.plsr.html#pls_model.eval',
                                      'mirzai.training.plsr.PLS_model.fit': 'https://franckalbinet.github.io/mirzai/training.plsr.html#pls_model.fit',
                                      'mirzai.training.plsr.PLS_model.predict': 'https://franckalbinet.github.io/mirzai/training.plsr.html#pls_model.predict',
                                      'mirzai.training.plsr.compute_valid_curve': 'https://franckalbinet.github.io/mirzai/training.plsr.html#compute_valid_curve'},
            'mirzai.vis.core': { 'mirzai.vis.core.ACCENT_COLOR': 'https://franckalbinet.github.io/mirzai/vis.core.html#accent_color',
                                 'mirzai.vis.core.DEFAULT_STYLE': 'https://franckalbinet.github.io/mirzai/vis.core.html#default_style',
                                 'mirzai.vis.core.PRIMARY_COLOR': 'https://franckalbinet.github.io/mirzai/vis.core.html#primary_color',
                                 'mirzai.vis.core.centimeter': 'https://franckalbinet.github.io/mirzai/vis.core.html#centimeter',
                                 'mirzai.vis.core.plot_capacity': 'https://franckalbinet.github.io/mirzai/vis.core.html#plot_capacity',
                                 'mirzai.vis.core.plot_learning_curve': 'https://franckalbinet.github.io/mirzai/vis.core.html#plot_learning_curve',
                                 'mirzai.vis.core.plot_spectra': 'https://franckalbinet.github.io/mirzai/vis.core.html#plot_spectra',
                                 'mirzai.vis.core.plot_validation_curve': 'https://franckalbinet.github.io/mirzai/vis.core.html#plot_validation_curve',
                                 'mirzai.vis.core.set_style': 'https://franckalbinet.github.io/mirzai/vis.core.html#set_style',
                                 'mirzai.vis.core.summary_plot': 'https://franckalbinet.github.io/mirzai/vis.core.html#summary_plot'}}}